@@ -89,7 +89,7 @@ SIGN_PERSONAL_SEAL - 个人签署印章控件；
 
 表单域的控件不能作为印章和签名控件
         :type ComponentType: str
-        :param ComponentName: 控件名称
+        :param ComponentName: 控件简称
         :type ComponentName: str
         :param ComponentRequired: 定义控件是否为必填项，默认为false
         :type ComponentRequired: bool
@@ -404,7 +404,7 @@ class DescribeTemplatesRequest(AbstractModel):
         :type Agent: :class:`tencentcloud.essbasic.v20210526.models.Agent`
         :param Operator: 操作者的信息
         :type Operator: :class:`tencentcloud.essbasic.v20210526.models.UserInfo`
-        :param TemplateId: 模版唯一标识,可以通过模版列表处获取
+        :param TemplateId: 模版唯一标识
         :type TemplateId: str
         """
         self.Agent = None
